﻿using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 리스트 컬렉션 뷰
        /// </summary>
        private ListCollectionView listCollectionView;

        /// <summary>
        /// 주문
        /// </summary>
        private Order order;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            this.listCollectionView = (ListCollectionView)CollectionViewSource.GetDefaultView(this.dockPanel.DataContext);

            this.orderIDHeaderButton.Click     += headerButton_Click;
            this.customerIDHeaderButton.Click  += headerButton_Click;
            this.productNameHeaderButton.Click += headerButton_Click;
            this.productIDHeaderButton.Click   += headerButton_Click;
            this.filledHeaderButton.Click      += headerButton_Click;
            this.movePreviousItemButton.Click  += moveItemButton_Click;
            this.moveNextItemButton.Click      += moveItemButton_Click;
            this.filterButton.Click            += filterButton_Click;
            this.unfilterButton.Click          += filterButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 헤더 버튼 클릭시 처리하기 - headerButton_Click(sender, e)

        /// <summary>
        /// 헤더 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void headerButton_Click(object sender, RoutedEventArgs e)
        {
            Button button = sender as Button;

            this.listCollectionView.SortDescriptions.Clear();

            switch(button.Name)
            {
                case "orderIDHeaderButton" :

                    this.listCollectionView.SortDescriptions.Add(new SortDescription("OrderID", ListSortDirection.Ascending));

                    break;

                case "customerIDHeaderButton" :

                    this.listCollectionView.SortDescriptions.Add(new SortDescription("CustomerID", ListSortDirection.Ascending));

                    break;

                case "productNameHeaderButton" :

                    this.listCollectionView.SortDescriptions.Add(new SortDescription("ProductName", ListSortDirection.Ascending));

                    break;

                case "productIDHeaderButton" :

                    this.listCollectionView.SortDescriptions.Add(new SortDescription("ProductID", ListSortDirection.Ascending));

                    break;

                case "filledHeaderButton" :

                    this.listCollectionView.SortDescriptions.Add(new SortDescription("Filled", ListSortDirection.Ascending));

                    break;
            }
        }

        #endregion
        #region 항목 이동 버튼 클릭시 처리하기 - moveItemButton_Click(sender, e)

        /// <summary>
        /// 항목 이동 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void moveItemButton_Click(object sender, RoutedEventArgs e)
        {
            Button button = sender as Button;

            switch(button.Name)
            {
                case "movePreviousItemButton" :

                    if(this.listCollectionView.MoveCurrentToPrevious())
                    {
                        this.feedbackTextBlock.Text = string.Empty;

                        this.order = this.listCollectionView.CurrentItem as Order;
                    }
                    else
                    {
                        this.listCollectionView.MoveCurrentToFirst();

                        this.feedbackTextBlock.Text = "At first record";
                    }

                    break;

                case "moveNextItemButton" :

                    if(this.listCollectionView.MoveCurrentToNext())
                    {
                        this.feedbackTextBlock.Text = string.Empty;

                        this.order = this.listCollectionView.CurrentItem as Order;
                    }
                    else
                    {
                        this.listCollectionView.MoveCurrentToLast();

                        this.feedbackTextBlock.Text = "At last record";
                    }

                    break;
            }
        }

        #endregion
        #region 필터 버튼 클릭시 처리하기 - filterButton_Click(sender, e)

        /// <summary>
        /// 필터 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void filterButton_Click(object sender, RoutedEventArgs e)
        {
            Button button = sender as Button;

            switch(button.Name)
            {
                case "filterButton"   : this.listCollectionView.Filter = Contains; break;
                case "unfilterButton" : this.listCollectionView.Filter = null;     break;
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 포함 여부 구하기 - Contains(source)

        /// <summary>
        /// 포함 여부 구하기
        /// </summary>
        /// <param name="source">소스 객체</param>
        /// <returns>포함 여부</returns>
        private bool Contains(object source)
        {
            Order order = source as Order;

            return order?.Filled == "No";
        }

        #endregion
    }
}